@@ -4,7 +4,7 @@
 
 from django.conf import settings
 
-__version__ = '1.0.0'
+__version__ = '2.1.1'
 
 
 def enable_error_logging_in_debug_mode():
@@ -18,7 +18,7 @@ def enable_error_logging_in_debug_mode():
 
         orig_technical_500_response = debug.technical_500_response
 
-        def custom_technical_500_response(request, exc_type, exc_value, tb):
+        def custom_technical_500_response(request, exc_type, exc_value, tb, status_code=None):
             """
             Create a technical server error response. The last three arguments are
             the values returned from sys.exc_info() and friends.
@@ -28,6 +28,6 @@ def enable_error_logging_in_debug_mode():
                 exc_info=(exc_type, exc_value, tb),
                 extra={'status_code': 500, 'request': request}
             )
-            return orig_technical_500_response(request, exc_type, exc_value, tb)
+            return orig_technical_500_response(request, exc_type, exc_value, tb, status_code=status_code)
 
         debug.technical_500_response = custom_technical_500_response
